Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorIan Thompson <quornian@googlemail.com>2008-10-05 01:04:16 +0400
committerIan Thompson <quornian@googlemail.com>2008-10-05 01:04:16 +0400
commit04226f6f3f505bc70a0898fbf9d6ea555449520a (patch)
tree61877907bfb8b22de6856d040773cb206455ca2e /source
parent7d77b58900b5446ab90fc875bd9e6166126443af (diff)
Bugfix for [#17748] "Copy and paste under window since rev 16769"
Now actually copies to the clipboard on copy/cut when editing UI fields.
Diffstat (limited to 'source')
-rw-r--r--source/blender/src/interface.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/source/blender/src/interface.c b/source/blender/src/interface.c
index a8c23864afd..7c1a4668a56 100644
--- a/source/blender/src/interface.c
+++ b/source/blender/src/interface.c
@@ -1843,13 +1843,14 @@ static int ui_do_but_TEX(uiBut *but)
}
/* cut & copy */
else if ( (dev==XKEY) || (dev==CKEY) ) {
/* copy the contents to the copypaste buffer */
for(x= but->selsta; x <= but->selend; x++) {
if (x==but->selend)
buf[x] = '\0';
else
buf[(x - but->selsta)] = str[x];
}
+ putClipboard(buf, 0);
/* for cut only, delete the selection afterwards */
if (dev==XKEY) {
@@ -1843,13 +1843,14 @@ static int ui_do_but_TEX(uiBut *but)
/* cut & copy */
else if ( (dev==XKEY) || (dev==CKEY) ) {
- /* copy the contents to the copypaste buffer */
+ /* copy the contents to the clipboard */
for(x= but->selsta; x <= but->selend; x++) {
if (x==but->selend)